--- title: "wallaroo.records.v1_tls_response" type: docs linkTitle: "wallaroo.records.v1_tls_response" ---
def from_str(x: Any) -> str:
def to_class(c: Type[~T], x: Any) -> dict:
class WallarooAPIGetTLSCERTV1:

Result from requesting the most recent TLS cert

WallarooAPIGetTLSCERTV1(tls_certificate: str, tls_key: str)
tls_certificate: str

Text of the latest private key

@staticmethod
def from_dict(obj: Any) -> wallaroo.records.v1_tls_response.WallarooAPIGetTLSCERTV1:
def to_dict(self) -> dict:
def wallaroo_api_get_tlscertv1_from_dict(s: Any) -> wallaroo.records.v1_tls_response.WallarooAPIGetTLSCERTV1:
def wallaroo_api_get_tlscertv1_to_dict(x: wallaroo.records.v1_tls_response.WallarooAPIGetTLSCERTV1) -> Any: